@@ -73,7 +73,7 @@ public:
         : svgBuffers(0), addedPixmaps(0)
         { stepSerialNum(); }
 
-    ~QSvgIconEnginePrivate()
+    virtual ~QSvgIconEnginePrivate()
         { delete addedPixmaps; delete svgBuffers; }
 
     static inline int hashKey(QIcon::Mode mode, QIcon::State state)
@@ -147,7 +147,9 @@ void QSvgIconEnginePrivate::loadDataForModeAndState(DSvgRenderer *renderer, QIco
     }
     if (!buf.isEmpty()) {
 #ifndef QT_NO_COMPRESS
-        buf = qUncompress(buf);
+        if (Q_LIKELY(!qEnvironmentVariableIsSet("QT_NO_COMPRESS"))) {
+            buf = qUncompress(buf);
+        }
 #endif
         renderer->load(buf);
     } else {
@@ -215,7 +217,8 @@ QPixmap QSvgIconEngine::pixmap(const QSize &size, QIcon::Mode mode,
             if (d->svgBuffers && !d->svgBuffers->isEmpty())
                 mdst = QByteArray::number(d->hashKey(mode, state)).prepend("_");
             // svgFiles[-1] 是为了取到额外的cache key,例如会跟随颜色变化的svg图标，将会添加此特殊的标记
-            const QByteArray cacheKey = svgFile.toLocal8Bit() + d->svgFiles[-1].toLocal8Bit() + mdst; // add mode state to cachekey
+            const QByteArray extraKey = d->svgFiles.value(-1).isEmpty() ? QByteArrayLiteral("") : d->svgFiles.value(-1).toLocal8Bit() + mdst;
+            const QByteArray cacheKey = svgFile.toLocal8Bit() + extraKey; // add mode state to cachekey
             const QString &svgFileSha1 = QString::fromLatin1(QCryptographicHash::hash(cacheKey, QCryptographicHash::Sha1).toHex());
             cacheFile = QStringLiteral("%1/%2.png").arg(cachePath).arg(svgFileSha1);
         }
@@ -271,9 +274,9 @@ QPixmap QSvgIconEngine::pixmap(const QSize &size, QIcon::Mode mode,
                     if (image.save(&file, "png", 80) && file.commit()) {
                         QFileInfo svgFileInfo(svgFile);
                         // 不能直接使用QSaveFile改写文件的时间
-                        QFile file(cacheFile);
-                        if (!file.open(QFile::ReadWrite) || !file.setFileTime(svgFileInfo.lastModified(), QFileDevice::FileModificationTime)) {
-                            qCWarning(lcDSvg()) << "set cache file modified date time failed, error message:" << file.errorString()
+                        QFile timeFile(cacheFile);
+                        if (!timeFile.open(QFile::ReadWrite) || !timeFile.setFileTime(svgFileInfo.lastModified(), QFileDevice::FileModificationTime)) {
+                            qCWarning(lcDSvg()) << "set cache file modified date time failed, error message:" << timeFile.errorString()
                                                 << ", cache file:" << cacheFile << ", svg file:" << svgFile;
                         }
                     } else {
@@ -342,7 +345,7 @@ void QSvgIconEngine::addFile(const QString &fileName, const QSize &,
          const QString abs = fi.absoluteFilePath();
          const FileType type = fileType(fi);
 #ifndef QT_NO_COMPRESS
-         if (type == SvgFile || type == CompressedSvgFile) {
+         if ((type == SvgFile || type == CompressedSvgFile) && Q_LIKELY(!qEnvironmentVariableIsSet("QT_NO_COMPRESS"))) {
 #else
          if (type == SvgFile) {
 #endif
@@ -389,7 +392,8 @@ bool QSvgIconEngine::read(QDataStream &in)
         QHash<int, QString> fileNames;  // For memoryoptimization later
         in >> fileNames >> isCompressed >> *d->svgBuffers;
 #ifndef QT_NO_COMPRESS
-        if (!isCompressed) {
+
+        if (!isCompressed && Q_LIKELY(!qEnvironmentVariableIsSet("QT_NO_COMPRESS"))) {
             for (auto it = d->svgBuffers->begin(), end = d->svgBuffers->end(); it != end; ++it)
                 it.value() = qCompress(it.value());
         }
@@ -418,7 +422,9 @@ bool QSvgIconEngine::read(QDataStream &in)
         in >> data;
         if (!data.isEmpty()) {
 #ifndef QT_NO_COMPRESS
-            data = qUncompress(data);
+            if (Q_LIKELY(!qEnvironmentVariableIsSet("QT_NO_COMPRESS"))) {
+                data = qUncompress(data);
+            }
 #endif
             if (!data.isEmpty())
                 d->svgBuffers->insert(d->hashKey(QIcon::Normal, QIcon::Off), data);
@@ -444,7 +450,9 @@ bool QSvgIconEngine::write(QDataStream &out) const
     if (out.version() >= QDataStream::Qt_4_4) {
         int isCompressed = 0;
 #ifndef QT_NO_COMPRESS
-        isCompressed = 1;
+        if (Q_LIKELY(!qEnvironmentVariableIsSet("QT_NO_COMPRESS"))) {
+            isCompressed = 1;
+        }
 #endif
         QHash<int, QByteArray> svgBuffers;
         if (d->svgBuffers)
@@ -455,7 +463,9 @@ bool QSvgIconEngine::write(QDataStream &out) const
             if (f.open(QIODevice::ReadOnly))
                 buf = f.readAll();
 #ifndef QT_NO_COMPRESS
-            buf = qCompress(buf);
+            if (Q_LIKELY(!qEnvironmentVariableIsSet("QT_NO_COMPRESS"))) {
+                buf = qCompress(buf);
+            }
 #endif
             svgBuffers.insert(it.key(), buf);
         }
@@ -478,7 +488,9 @@ bool QSvgIconEngine::write(QDataStream &out) const
             }
         }
 #ifndef QT_NO_COMPRESS
-        buf = qCompress(buf);
+        if (Q_LIKELY(!qEnvironmentVariableIsSet("QT_NO_COMPRESS"))) {
+            buf = qCompress(buf);
+        }
 #endif
         out << buf;
         // 4.3 has buggy handling of added pixmaps, so don't write any
