@@ -29,6 +29,10 @@ namespace dstyle {
 class DStyleAnimation;
 }
 
+DWIDGET_BEGIN_NAMESPACE
+class DStyleOptionButtonBoxButton;
+DWIDGET_END_NAMESPACE
+
 namespace chameleon {
 
 class ChameleonStyle : public DStyle
@@ -65,16 +69,19 @@ public:
 private:
     void drawShadow(QPainter *p, const QRect &rect, const QColor &color) const;
     void drawBorder(QPainter *p, const QStyleOption *opt, const QWidget *w) const;
+    void drawCalenderEllipse(QPainter *p, const QRect &rect, int offset) const;
+    void drawButtonBoxButton(const DStyleOptionButtonBoxButton *btnopt, QPainter *p, const QRect &rect, int radius) const;
     void drawRoundedShadow(QPainter *p, const QRect &rect, const QColor &color,int frame_radius) const;
     bool isNoticks(const QStyleOptionSlider *slider, QPainter *p, const QWidget *w) const;
 
     QColor getColor(const QStyleOption *option, QPalette::ColorRole role) const;
     QColor getColor(const QStyleOption *option, DPalette::ColorType type, const QWidget *widget) const;
+    QBrush getBrush(const QStyleOption *option, DPalette::ColorRole type) const;
     QMargins frameExtentMargins() const;
     QRect drawButtonDownArrow(const QStyleOption *opt, QPainter *p, const QWidget *w) const;
 
-    bool drawSpinBox(const QStyleOptionSpinBox *opt, QPainter *p, const QWidget *w) const;
-    void updateSpinBoxButtonState(const QStyleOptionSpinBox *opt, QStyleOptionButton& button, bool isActive, bool isEnabled) const;
+    bool drawSpinBox(const QStyleOptionSpinBox *opt, QPainter *painter, const QWidget *widget) const;
+    void updateSpinBoxButtonState(const QStyleOptionSpinBox *opt, QStyleOptionButton& buttonOpt, bool isActive, bool isEnabled) const;
     bool drawMenuBarItem(const QStyleOptionMenuItem *option, QRect &rect, QPainter *painter, const QWidget *widget) const;
     void drawMenuItemBackground(const QStyleOption *option, QPainter *painter, QStyleOptionMenuItem::MenuItemType type) const;
     bool drawMenuItem(const QStyleOptionMenuItem *option, QPainter *painter, const QWidget *widget) const;
@@ -83,13 +90,14 @@ private:
     bool drawTabBarCloseButton(QPainter *painter,const QStyleOption *tab , const QWidget *widget) const;
     bool drawTabBarScrollButton(QPainter *painter, const QStyleOption *opt, const QWidget *buttonWidget) const;
     bool drawComboBox(QPainter *painter, const QStyleOptionComboBox *comboBox, const QWidget *widget) const;
-    bool drawComboBoxLabel(QPainter *painter, const QStyleOptionComboBox *comboBox, const QWidget *widget) const;
+    bool drawComboBoxLabel(QPainter *painter, const QStyleOptionComboBox *cb, const QWidget *widget) const;
     void drawSliderHandle(const QStyleOptionComplex *opt, QRectF& rectHandle, QPainter *p, const QWidget *w) const;
     void drawSliderHandleFocus(const QStyleOptionComplex *opt, QRectF& rectHandle, QPainter *p, const QWidget *w) const;
     void drawIcon(const QStyleOption *opt, QPainter *p, QRect &rect, const QIcon &icon, bool checked = false) const;
     void tabLayout(const QStyleOptionTab *opt, const QWidget *widget, QRect *textRect, QRect *iconRect) const;
     bool drawTableViewItem(QStyle::PrimitiveElement pe, const QStyleOption *opt, QPainter *p,
                        const QWidget *w = nullptr) const;
+    bool hideScrollBarByAnimation(const QStyleOptionSlider *scrollBar, QPainter *p) const;
 
 public:
 #ifndef QT_NO_ANIMATION
@@ -98,6 +106,10 @@ public:
     void _q_removeAnimation();
 #endif
 
+protected:
+    void drawMenuItemRedPoint(const QStyleOptionMenuItem *option, QPainter *painter, const QWidget *widget) const;
+    void resetAttribute(QWidget *w, bool polish);
+
 private:
     mutable QHash<const QObject*, dstyle::DStyleAnimation*> animations;
 };
