@@ -72,6 +72,10 @@ enum Metrics
     ToolButton_MarginWidth = 6,
     ToolButton_ItemSpacing = 4,
     ToolButton_InlineIndicatorWidth = 12,
+    ToolButton_AlignLeftPadding = 10,
+    ToolButton_AlignCenterPadding = 8,
+    ToolButton_AlignRightPadding = 9,
+    ToolButton_AlignLeftMargin = 7,
 
     // checkboxes and radio buttons
     CheckBox_Size = 20,
@@ -145,6 +149,8 @@ enum Metrics
     TabBar_TabOverlap = 0,
     TabBar_BaseOverlap = 0,
     TabBar_TabMargin = 10,
+    TabBar_TabButtonSize = 22,      // 标签页按钮大小
+    TabletTabBar_TabButtonSize = 36,// 平板环境标签页按钮大小
 
     // tab widget
     TabWidget_MarginWidth = 4,
